##  Access the Workspace
Admins of the workplace provide access to users. Depending on the setup, you can either access with your organizations single-sign on credentials or by following the instructions you’ll receive with an invitation email.
In case you have been invited to more than one workspace, you can select the workspace you want to access.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe34983bc81504d11a569f43d3f9a6e55_HiRes.png)
One of the first steps after gaining access is to complete your profile. It includes resetting the password, updating personal information and configuring notification settings if need be. For more detailed instructions, see [User Profile](https://help.sap.com/docs/leanix/ea/user-profile?locale=en-US&state=PRODUCTION&version=CLOUD "Manage your user profile settings. Change or reset your password if needed.").
